#version 130
precision mediump float;

// LIGHT
uniform vec3 light_position;
uniform vec4 light_color;
uniform vec4 ambient_color;

//in vec4 frag_color;

// TEXTURE

// this uniform does not have to be set from outside since it is always 0
uniform sampler2D myTexture;
in vec2 vTexCoord;
uniform float phong;

// SHADOW
uniform sampler2DShadow shadowmap;

// FRAGMENT
in vec3 world_normal;
in vec4 world_position;
in vec4 SM_tex_coord;

// OUTPUT
out vec4 fragColor;

void main() {
 vec4 color = texture(myTexture, vTexCoord);

 //vec3 tex_coords = SM_tex_coord.xyz/SM_tex_coord.w;
 
// float depth = texture(shadowmap, tex_coords.xy).r;
// float inShadow = (depth < tex_coords.z) ? 1.0 : 0.0;
 float schatten = textureProj(shadowmap,SM_tex_coord);
 vec3 normal = normalize(world_normal);
 vec3 position = world_position.xyz / world_position.w;
 vec3 light_dir = normalize(light_position - position);

 vec4 ambient = ambient_color*color;
 vec4 diffuse = color*light_color*max(0.0, dot(normal, light_dir));

 // provisional phong shading ;)
 vec3 v = world_position.xyz;
 vec3 L = normalize(light_position - v);
 vec3 E = normalize(-v);
 vec3 R = normalize(-reflect(L,world_normal));
 vec4 specular = vec4(1.0f, 1.0f, 1.0f, 0.0f)*pow(max(dot(R,E),0.0),0.3*30.0f);
 specular = clamp(specular, 0.0, 1.0);
 
 //fragColor = ambient + diffuse; // + specular;
 fragColor =ambient + diffuse * vec4(schatten,schatten,schatten,0.0f) + specular*phong;
}
